@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -29,6 +29,7 @@
 #include <string.h>
 #include <panel-applet.h>
 #include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib-object.h>
 #include <dbus/dbus-glib.h>
@@ -93,12 +94,12 @@ static gboolean  gpm_applet_scroll_cb             (GpmBrightnessApplet *applet,
 static gboolean  gpm_applet_slide_cb              (GtkWidget *w, GpmBrightnessApplet *applet);
 static void      gpm_applet_create_popup          (GpmBrightnessApplet *applet);
 static gboolean  gpm_applet_popup_cb              (GpmBrightnessApplet *applet, GdkEventButton *event);
-static void      gpm_applet_dialog_about_cb       (BonoboUIComponent *uic, gpointer data, const gchar *verbname);
+static void      gpm_applet_dialog_about_cb       (GtkAction *action, gpointer data);
 static gboolean  gpm_applet_bonobo_cb             (PanelApplet *_applet, const gchar *iid, gpointer data);
 static void      gpm_applet_destroy_cb            (GtkObject *object);
 
-#define GPM_BRIGHTNESS_APPLET_OAFID		"OAFIID:GNOME_BrightnessApplet"
-#define GPM_BRIGHTNESS_APPLET_FACTORY_OAFID	"OAFIID:GNOME_BrightnessApplet_Factory"
+#define GPM_BRIGHTNESS_APPLET_ID		"BrightnessApplet"
+#define GPM_BRIGHTNESS_APPLET_FACTORY_ID	"BrightnessAppletFactory"
 #define GPM_BRIGHTNESS_APPLET_ICON		"gnome-brightness-applet"
 #define GPM_BRIGHTNESS_APPLET_ICON_DISABLED	"gpm-brightness-lcd-disabled"
 #define GPM_BRIGHTNESS_APPLET_ICON_INVALID	"gpm-brightness-lcd-invalid"
@@ -224,17 +225,20 @@ gpm_applet_get_icon (GpmBrightnessApplet *applet)
 static void
 gpm_applet_check_size (GpmBrightnessApplet *applet)
 {
+	GtkAllocation allocation;
+
 	/* we don't use the size function here, but the yet allocated size because the
 	   size value is false (kind of rounded) */
+	gtk_widget_get_allocation (GTK_WIDGET (applet), &allocation);
 	if (PANEL_APPLET_VERTICAL(panel_applet_get_orient (PANEL_APPLET (applet)))) {
-		if (applet->size != GTK_WIDGET(applet)->allocation.width) {
-			applet->size = GTK_WIDGET(applet)->allocation.width;
+		if (applet->size != allocation.width) {
+			applet->size = allocation.width;
 			gpm_applet_get_icon (applet);
 			gtk_widget_set_size_request (GTK_WIDGET(applet), applet->size, applet->icon_height + 2);
 		}
 	} else {
-		if (applet->size != GTK_WIDGET(applet)->allocation.height) {
-			applet->size = GTK_WIDGET(applet)->allocation.height;
+		if (applet->size != allocation.height) {
+			applet->size = allocation.height;
 			gpm_applet_get_icon (applet);
 			gtk_widget_set_size_request (GTK_WIDGET(applet), applet->icon_width + 2, applet->size);
 		}
@@ -254,8 +258,9 @@ gpm_applet_draw_cb (GpmBrightnessApplet *applet)
 	GdkColor color;
 	GdkGC *gc;
 	GdkPixmap *background;
+	GtkAllocation allocation;
 
-	if (GTK_WIDGET(applet)->window == NULL) {
+	if (gtk_widget_get_window (GTK_WIDGET(applet)) == NULL) {
 		return FALSE;
 	}
 
@@ -271,23 +276,24 @@ gpm_applet_draw_cb (GpmBrightnessApplet *applet)
 		return FALSE;
 	}
 
-	w = GTK_WIDGET(applet)->allocation.width;
-	h = GTK_WIDGET(applet)->allocation.height;
+	gtk_widget_get_allocation (GTK_WIDGET (applet), &allocation);
+	w = allocation.width;
+	h = allocation.height;
 
-	gc = gdk_gc_new (GTK_WIDGET(applet)->window);
+	gc = gdk_gc_new (gtk_widget_get_window (GTK_WIDGET(applet)));
 
 	/* draw pixmap background */
 	bg_type = panel_applet_get_background (PANEL_APPLET (applet), &color, &background);
 	if (bg_type == PANEL_PIXMAP_BACKGROUND && !applet->popped) {
 		/* fill with given background pixmap */
-		gdk_draw_drawable (GTK_WIDGET(applet)->window, gc, background, 0, 0, 0, 0, w, h);
+		gdk_draw_drawable (gtk_widget_get_window (GTK_WIDGET(applet)), gc, background, 0, 0, 0, 0, w, h);
 	}
 	
 	/* draw color background */
 	if (bg_type == PANEL_COLOR_BACKGROUND && !applet->popped) {
 		gdk_gc_set_rgb_fg_color (gc,&color);
 		gdk_gc_set_fill (gc,GDK_SOLID);
-		gdk_draw_rectangle (GTK_WIDGET(applet)->window, gc, TRUE, 0, 0, w, h);
+		gdk_draw_rectangle (gtk_widget_get_window (GTK_WIDGET(applet)), gc, TRUE, 0, 0, w, h);
 	}
 
 	/* fill with selected color if popped */
@@ -295,11 +301,11 @@ gpm_applet_draw_cb (GpmBrightnessApplet *applet)
 		color = gtk_rc_get_style (GTK_WIDGET(applet))->bg[GTK_STATE_SELECTED];
 		gdk_gc_set_rgb_fg_color (gc,&color);
 		gdk_gc_set_fill (gc,GDK_SOLID);
-		gdk_draw_rectangle (GTK_WIDGET(applet)->window, gc, TRUE, 0, 0, w, h);
+		gdk_draw_rectangle (gtk_widget_get_window (GTK_WIDGET(applet)), gc, TRUE, 0, 0, w, h);
 	}
 
 	/* draw icon at center */
-	gdk_draw_pixbuf (GTK_WIDGET(applet)->window, gc, applet->icon,
+	gdk_draw_pixbuf (gtk_widget_get_window (GTK_WIDGET(applet)), gc, applet->icon,
 			 0, 0, (w - applet->icon_width)/2, (h - applet->icon_height)/2,
 			 applet->icon_width, applet->icon_height,
 			 GDK_RGB_DITHER_NONE, 0, 0);
@@ -590,7 +596,6 @@ gpm_applet_create_popup (GpmBrightnessApplet *applet)
 
 	/* window */
 	applet->popup = gtk_window_new (GTK_WINDOW_POPUP);
-	GTK_WIDGET_UNSET_FLAGS (applet->popup, GTK_TOPLEVEL);
 	gtk_window_set_type_hint (GTK_WINDOW(applet->popup), GDK_WINDOW_TYPE_HINT_UTILITY);
 	gtk_widget_set_parent (applet->popup, GTK_WIDGET(applet));
 	gtk_container_add (GTK_CONTAINER(applet->popup), frame);
@@ -605,6 +610,7 @@ gpm_applet_create_popup (GpmBrightnessApplet *applet)
 static gboolean
 gpm_applet_popup_cb (GpmBrightnessApplet *applet, GdkEventButton *event)
 {
+	GtkAllocation allocation, popup_allocation;
 	gint orientation, x, y;
 
 	/* react only to left mouse button */
@@ -644,36 +650,32 @@ gpm_applet_popup_cb (GpmBrightnessApplet *applet, GdkEventButton *event)
 
 	/* retrieve geometry parameters and move window appropriately */
 	orientation = panel_applet_get_orient (PANEL_APPLET (PANEL_APPLET (applet)));
-	gdk_window_get_origin (GTK_WIDGET(applet)->window, &x, &y);
+	gdk_window_get_origin (gtk_widget_get_window (GTK_WIDGET(applet)), &x, &y);
 
+	gtk_widget_get_allocation (GTK_WIDGET (applet), &allocation);
+	gtk_widget_get_allocation (GTK_WIDGET (applet->popup), &popup_allocation);
 	switch (orientation) {
 	case PANEL_APPLET_ORIENT_DOWN:
-		x += GTK_WIDGET(applet)->allocation.x
-			+ GTK_WIDGET(applet)->allocation.width/2;
-		y += GTK_WIDGET(applet)->allocation.y
-			+ GTK_WIDGET(applet)->allocation.height;
-		x -= applet->popup->allocation.width/2;
+		x += allocation.x + allocation.width/2;
+		y += allocation.y + allocation.height;
+		x -= popup_allocation.width/2;
 		break;
 	case PANEL_APPLET_ORIENT_UP:
-		x += GTK_WIDGET(applet)->allocation.x
-			+ GTK_WIDGET(applet)->allocation.width/2;
-		y += GTK_WIDGET(applet)->allocation.y;
-		x -= applet->popup->allocation.width/2;
-		y -= applet->popup->allocation.height;
+		x += allocation.x + allocation.width/2;
+		y += allocation.y;
+		x -= popup_allocation.width/2;
+		y -= popup_allocation.height;
 		break;
 	case PANEL_APPLET_ORIENT_RIGHT:
-		y += GTK_WIDGET(applet)->allocation.y
-			+ GTK_WIDGET(applet)->allocation.height/2;
-		x += GTK_WIDGET(applet)->allocation.x
-			+ GTK_WIDGET(applet)->allocation.width;
-		y -= applet->popup->allocation.height/2;
+		y += allocation.y + allocation.height/2;
+		x += allocation.x + allocation.width;
+		y -= popup_allocation.height/2;
 		break;
 	case PANEL_APPLET_ORIENT_LEFT:
-		y += GTK_WIDGET(applet)->allocation.y
-			+ GTK_WIDGET(applet)->allocation.height/2;
-		x += GTK_WIDGET(applet)->allocation.x;
-		x -= applet->popup->allocation.width;
-		y -= applet->popup->allocation.height/2;
+		y += allocation.y + allocation.height/2;
+		x += allocation.x;
+		x -= popup_allocation.width;
+		y -= popup_allocation.height/2;
 		break;
 	default:
 		g_assert_not_reached ();
@@ -684,12 +686,12 @@ gpm_applet_popup_cb (GpmBrightnessApplet *applet, GdkEventButton *event)
 	/* grab input */
 	gtk_widget_grab_focus (GTK_WIDGET(applet));
 	gtk_grab_add (GTK_WIDGET(applet));
-	gdk_pointer_grab (GTK_WIDGET(applet)->window, TRUE,
+	gdk_pointer_grab (gtk_widget_get_window (GTK_WIDGET(applet)), TRUE,
 			  GDK_BUTTON_PRESS_MASK |
 			  GDK_BUTTON_RELEASE_MASK |
 			  GDK_POINTER_MOTION_MASK,
 			  NULL, NULL, GDK_CURRENT_TIME);
-	gdk_keyboard_grab (GTK_WIDGET(applet)->window,
+	gdk_keyboard_grab (gtk_widget_get_window (GTK_WIDGET(applet)),
 			   TRUE, GDK_CURRENT_TIME);
 	gtk_widget_set_state (GTK_WIDGET(applet), GTK_STATE_SELECTED);
 
@@ -726,7 +728,7 @@ gpm_applet_stop_scroll_events_cb (GtkWidget *widget, GdkEvent  *event)
  * displays about dialog
  **/
 static void
-gpm_applet_dialog_about_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
+gpm_applet_dialog_about_cb (GtkAction *action, gpointer data)
 {
 	GtkAboutDialog *about;
 
@@ -791,7 +793,7 @@ gpm_applet_dialog_about_cb (BonoboUIComponent *uic, gpointer data, const gchar *
  * open gpm help
  **/
 static void
-gpm_applet_help_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
+gpm_applet_help_cb (GtkAction *action, gpointer data)
 {
 	gpm_help_display ("applets-brightness");
 }
@@ -990,44 +992,56 @@ gpm_brightness_applet_init (GpmBrightnessApplet *applet)
 }
 
 /**
- * gpm_applet_bonobo_cb:
- * @_applet: GpmBrightnessApplet instance created by the bonobo factory
- * @iid: Bonobo id
+ * gpm_applet_cb:
+ * @_applet: GpmBrightnessApplet instance created by the applet factory
+ * @iid: Applet id
  *
- * the function called by bonobo factory after creation
+ * the function called by libpanel-applet factory after creation
  **/
 static gboolean
-gpm_applet_bonobo_cb (PanelApplet *_applet, const gchar *iid, gpointer data)
+gpm_applet_cb (PanelApplet *_applet, const gchar *iid, gpointer data)
 {
 	GpmBrightnessApplet *applet = GPM_BRIGHTNESS_APPLET(_applet);
+	GtkActionGroup *action_group;
+	gchar *ui_path;
 
-	static BonoboUIVerb verbs [] = {
-		BONOBO_UI_VERB ("About", gpm_applet_dialog_about_cb),
-		BONOBO_UI_VERB ("Help", gpm_applet_help_cb),
-		BONOBO_UI_VERB_END
+	static const GtkActionEntry menu_actions [] = {
+		{ "About", GTK_STOCK_ABOUT, N_("_About"),
+		  NULL, NULL,
+		  G_CALLBACK (gpm_applet_dialog_about_cb) },
+		{ "Help", GTK_STOCK_HELP, N_("_Help"),
+		  NULL, NULL,
+		  G_CALLBACK (gpm_applet_help_cb) }
 	};
 
-	if (strcmp (iid, GPM_BRIGHTNESS_APPLET_OAFID) != 0) {
+	if (strcmp (iid, GPM_BRIGHTNESS_APPLET_ID) != 0) {
 		return FALSE;
 	}
 
-	panel_applet_setup_menu_from_file (PANEL_APPLET (applet),
-					   DATADIR,
-					   "GNOME_BrightnessApplet.xml",
-					   NULL, verbs, applet);
+	action_group = gtk_action_group_new ("Brightness Applet Actions");
+	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
+	gtk_action_group_add_actions (action_group,
+				      menu_actions,
+				      G_N_ELEMENTS (menu_actions),
+				      applet);
+	ui_path = g_build_filename (BRIGHTNESS_MENU_UI_DIR, "brightness-applet-menu.xml", NULL);
+	panel_applet_setup_menu_from_file (PANEL_APPLET (applet), ui_path, action_group);
+	g_free (ui_path);
+	g_object_unref (action_group);
+
 	gpm_applet_draw_cb (applet);
 	return TRUE;
 }
 
 /**
- * this generates a main with a bonobo factory
+ * this generates a main with a applet factory
  **/
-PANEL_APPLET_BONOBO_FACTORY
+PANEL_APPLET_OUT_PROCESS_FACTORY
  (/* the factory iid */
- GPM_BRIGHTNESS_APPLET_FACTORY_OAFID,
+ GPM_BRIGHTNESS_APPLET_FACTORY_ID,
  /* generates brighness applets instead of regular gnome applets  */
  GPM_TYPE_BRIGHTNESS_APPLET,
- /* the applet name and version */
- "BrightnessApplet", VERSION,
+ /* the applet name */
+ "BrightnessApplet",
  /* our callback (with no user data) */
- gpm_applet_bonobo_cb, NULL);
+ gpm_applet_cb, NULL);
