@@ -29,7 +29,7 @@
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 #include <X11/XF86keysym.h>
-#include <devkit-power-gobject/devicekit-power.h>
+#include <libupower-glib/upower.h>
 
 #include "gpm-common.h"
 #include "gpm-button.h"
@@ -48,7 +48,7 @@ struct GpmButtonPrivate
 	gchar			*last_button;
 	GTimer			*timer;
 	gboolean		 lid_is_closed;
-	DkpClient		*client;
+	UpClient		*client;
 };
 
 enum {
@@ -255,14 +255,8 @@ gpm_button_class_init (GpmButtonClass *klass)
 gboolean
 gpm_button_is_lid_closed (GpmButton *button)
 {
-	gboolean lid_is_closed;
-
 	g_return_val_if_fail (GPM_IS_BUTTON (button), FALSE);
-
-	g_object_get (button->priv->client,
-		      "lid-is-closed", &lid_is_closed,
-		      NULL);
-	return lid_is_closed;
+	return 	up_client_get_lid_is_closed (button->priv->client);
 }
 
 /**
@@ -283,14 +277,12 @@ gpm_button_reset_time (GpmButton *button)
  * gpm_button_client_changed_cb
  **/
 static void
-gpm_button_client_changed_cb (DkpClient *client, GpmButton *button)
+gpm_button_client_changed_cb (UpClient *client, GpmButton *button)
 {
 	gboolean lid_is_closed;
 
 	/* get new state */
-	g_object_get (client,
-		      "lid-is-closed", &lid_is_closed,
-		      NULL);
+	lid_is_closed = up_client_get_lid_is_closed (button->priv->client);
 
 	/* same state */
 	if (button->priv->lid_is_closed == lid_is_closed)
@@ -322,8 +314,8 @@ gpm_button_init (GpmButton *button)
 	button->priv->last_button = NULL;
 	button->priv->timer = g_timer_new ();
 
-	button->priv->lid_is_closed = FALSE;
-	button->priv->client = dkp_client_new ();
+	button->priv->client = up_client_new ();
+	button->priv->lid_is_closed = up_client_get_lid_is_closed (button->priv->client);
 	g_signal_connect (button->priv->client, "changed",
 			  G_CALLBACK (gpm_button_client_changed_cb), button);
 
