@@ -390,86 +390,3 @@ gpm_dpms_new (void)
 	return GPM_DPMS (gpm_dpms_object);
 }
 
-
-/***************************************************************************
- ***                          MAKE CHECK TESTS                           ***
- ***************************************************************************/
-#ifdef EGG_TEST
-#include "egg-test.h"
-
-void
-gpm_dpms_test (gpointer data)
-{
-	GpmDpms *dpms;
-	gboolean ret;
-	GError *error = NULL;
-	EggTest *test = (EggTest *) data;
-
-	if (!egg_test_start (test, "GpmDpms"))
-		return;
-
-	/************************************************************/
-	egg_test_title (test, "get object");
-	dpms = gpm_dpms_new ();
-	if (dpms != NULL)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "got no object");
-
-	/************************************************************/
-	egg_test_title (test, "set on");
-	ret = gpm_dpms_set_mode (dpms, GPM_DPMS_MODE_ON, &error);
-	if (ret)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed: %s", error->message);
-
-	g_usleep (2*1000*1000);
-
-	/************************************************************/
-	egg_test_title (test, "set STANDBY");
-	ret = gpm_dpms_set_mode (dpms, GPM_DPMS_MODE_STANDBY, &error);
-	if (ret)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed: %s", error->message);
-
-	g_usleep (2*1000*1000);
-
-	/************************************************************/
-	egg_test_title (test, "set SUSPEND");
-	ret = gpm_dpms_set_mode (dpms, GPM_DPMS_MODE_SUSPEND, &error);
-	if (ret)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed: %s", error->message);
-
-	g_usleep (2*1000*1000);
-
-	/************************************************************/
-	egg_test_title (test, "set OFF");
-	ret = gpm_dpms_set_mode (dpms, GPM_DPMS_MODE_OFF, &error);
-	if (ret)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed: %s", error->message);
-
-	g_usleep (2*1000*1000);
-
-	/************************************************************/
-	egg_test_title (test, "set on");
-	ret = gpm_dpms_set_mode (dpms, GPM_DPMS_MODE_ON, &error);
-	if (ret)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed: %s", error->message);
-
-	g_usleep (2*1000*1000);
-
-	g_object_unref (dpms);
-
-	egg_test_end (test);
-}
-
-#endif
-
