@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -30,8 +30,6 @@
 #include "gpm-graph-widget.h"
 
 #include "egg-debug.h"
-#include "egg-color.h"
-#include "egg-precision.h"
 
 G_DEFINE_TYPE (GpmGraphWidget, gpm_graph_widget, GTK_TYPE_DRAWING_AREA);
 #define GPM_GRAPH_WIDGET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_GRAPH_WIDGET, GpmGraphWidgetPrivate))
@@ -131,10 +129,10 @@ gpm_graph_widget_key_data_add (GpmGraphWidget *graph, guint32 color, const gchar
 }
 
 /**
- * dkp_graph_get_property:
+ * up_graph_get_property:
  **/
 static void
-dkp_graph_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
+up_graph_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 {
 	GpmGraphWidget *graph = GPM_GRAPH_WIDGET (object);
 	switch (prop_id) {
@@ -175,10 +173,10 @@ dkp_graph_get_property (GObject *object, guint prop_id, GValue *value, GParamSpe
 }
 
 /**
- * dkp_graph_set_property:
+ * up_graph_set_property:
  **/
 static void
-dkp_graph_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
+up_graph_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
 	GpmGraphWidget *graph = GPM_GRAPH_WIDGET (object);
 
@@ -234,8 +232,8 @@ gpm_graph_widget_class_init (GpmGraphWidgetClass *class)
 	GObjectClass *object_class = G_OBJECT_CLASS (class);
 
 	widget_class->expose_event = gpm_graph_widget_expose;
-	object_class->get_property = dkp_graph_get_property;
-	object_class->set_property = dkp_graph_set_property;
+	object_class->get_property = up_graph_get_property;
+	object_class->set_property = up_graph_set_property;
 	object_class->finalize = gpm_graph_widget_finalize;
 
 	g_type_class_add_private (class, sizeof (GpmGraphWidgetPrivate));
@@ -691,8 +689,8 @@ gpm_graph_widget_autorange_x (GpmGraphWidget *graph)
 			rounding_x = 10 * 60;
 	}
 
-	graph->priv->start_x = egg_precision_round_down (smallest_x, rounding_x);
-	graph->priv->stop_x = egg_precision_round_up (biggest_x, rounding_x);
+	graph->priv->start_x = gpm_precision_round_down (smallest_x, rounding_x);
+	graph->priv->stop_x = gpm_precision_round_up (biggest_x, rounding_x);
 
 	egg_debug ("Processed(1) range is %i<x<%i",
 		   graph->priv->start_x, graph->priv->stop_x);
@@ -785,8 +783,8 @@ gpm_graph_widget_autorange_y (GpmGraphWidget *graph)
 			rounding_y = 10 * 60;
 	}
 
-	graph->priv->start_y = egg_precision_round_down (smallest_y, rounding_y);
-	graph->priv->stop_y = egg_precision_round_up (biggest_y, rounding_y);
+	graph->priv->start_y = gpm_precision_round_down (smallest_y, rounding_y);
+	graph->priv->stop_y = gpm_precision_round_up (biggest_y, rounding_y);
 
 	/* a factor graph always is centered around zero */
 	if (graph->priv->type_y == GPM_GRAPH_WIDGET_TYPE_FACTOR) {
@@ -822,7 +820,7 @@ static void
 gpm_graph_widget_set_color (cairo_t *cr, guint32 color)
 {
 	guint8 r, g, b;
-	egg_color_to_rgb (color, &r, &g, &b);
+	gpm_color_to_rgb (color, &r, &g, &b);
 	cairo_set_source_rgb (cr, ((gdouble) r)/256.0f, ((gdouble) g)/256.0f, ((gdouble) b)/256.0f);
 }
 
