@@ -38,10 +38,11 @@
 #include <gtk/gtk.h>
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
-#include <gconf/gconf-client.h>
 #include <canberra-gtk.h>
 #include <libupower-glib/upower.h>
+#ifdef HAVE_NOTIFY
 #include <libnotify/notify.h>
+#endif
 
 #include "egg-debug.h"
 #include "egg-console-kit.h"
@@ -76,7 +77,7 @@ static void     gpm_manager_finalize	(GObject	 *object);
 struct GpmManagerPrivate
 {
 	GpmButton		*button;
-	GConfClient		*conf;
+	GSettings		*settings;
 	GpmDisks		*disks;
 	GpmDpms			*dpms;
 	GpmIdle			*idle;
@@ -196,7 +197,7 @@ gpm_manager_play_loop_start (GpmManager *manager, GpmManagerSound action, gboole
 	gboolean ret;
 	gint retval;
 
-	ret = gconf_client_get_bool (manager->priv->conf, GPM_CONF_UI_ENABLE_SOUND, NULL);
+	ret = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_ENABLE_SOUND);
 	if (!ret && !force) {
 		egg_debug ("ignoring sound due to policy");
 		return FALSE;
@@ -234,6 +235,9 @@ gpm_manager_play_loop_start (GpmManager *manager, GpmManagerSound action, gboole
 	manager->priv->critical_alert_timeout_id = g_timeout_add_seconds (timeout,
 									  (GSourceFunc) gpm_manager_play_loop_timeout_cb,
 									  manager);
+#if GLIB_CHECK_VERSION(2,25,8)
+	g_source_set_name_by_id (manager->priv->critical_alert_timeout_id, "[GpmManager] play-loop");
+#endif
 
 	/* play the sound, using sounds from the naming spec */
 	retval = ca_context_play (ca_gtk_context_get (), 0,
@@ -255,7 +259,7 @@ gpm_manager_play (GpmManager *manager, GpmManagerSound action, gboolean force)
 	gboolean ret;
 	gint retval;
 
-	ret = gconf_client_get_bool (manager->priv->conf, GPM_CONF_UI_ENABLE_SOUND, NULL);
+	ret = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_ENABLE_SOUND);
 	if (!ret && !force) {
 		egg_debug ("ignoring sound due to policy");
 		return FALSE;
@@ -349,11 +353,11 @@ gpm_manager_sync_policy_sleep (GpmManager *manager)
 	guint sleep_computer;
 
 	if (!manager->priv->on_battery) {
-		sleep_computer = gconf_client_get_int (manager->priv->conf, GPM_CONF_TIMEOUT_SLEEP_COMPUTER_AC, NULL);
-		sleep_display = gconf_client_get_int (manager->priv->conf, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_AC, NULL);
+		sleep_computer = g_settings_get_int (manager->priv->settings, GPM_SETTINGS_SLEEP_COMPUTER_AC);
+		sleep_display = g_settings_get_int (manager->priv->settings, GPM_SETTINGS_SLEEP_DISPLAY_AC);
 	} else {
-		sleep_computer = gconf_client_get_int (manager->priv->conf, GPM_CONF_TIMEOUT_SLEEP_COMPUTER_BATT, NULL);
-		sleep_display = gconf_client_get_int (manager->priv->conf, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_BATT, NULL);
+		sleep_computer = g_settings_get_int (manager->priv->settings, GPM_SETTINGS_SLEEP_COMPUTER_BATT);
+		sleep_display = g_settings_get_int (manager->priv->settings, GPM_SETTINGS_SLEEP_DISPLAY_BATT);
 	}
 
 	/* set the new sleep (inactivity) value */
@@ -380,7 +384,7 @@ gpm_manager_blank_screen (GpmManager *manager, GError **noerror)
 	GError *error = NULL;
 
 	do_lock = gpm_control_get_lock_policy (manager->priv->control,
-					       GPM_CONF_LOCK_ON_BLANK_SCREEN);
+					       GPM_SETTINGS_LOCK_ON_BLANK_SCREEN);
 	if (do_lock) {
 		if (!gpm_screensaver_lock (manager->priv->screensaver))
 			egg_debug ("Could not lock screen via gnome-screensaver");
@@ -416,7 +420,7 @@ gpm_manager_unblank_screen (GpmManager *manager, GError **noerror)
 		ret = FALSE;
 	}
 
-	do_lock = gpm_control_get_lock_policy (manager->priv->control, GPM_CONF_LOCK_ON_BLANK_SCREEN);
+	do_lock = gpm_control_get_lock_policy (manager->priv->control, GPM_SETTINGS_LOCK_ON_BLANK_SCREEN);
 	if (do_lock)
 		gpm_screensaver_poke (manager->priv->screensaver);
 	return ret;
@@ -547,7 +551,7 @@ gpm_manager_sleep_failure_response_cb (GtkDialog *dialog, gint response_id, GpmM
 
 	/* user clicked the help button */
 	if (response_id == GTK_RESPONSE_HELP) {
-		uri = gconf_client_get_string (manager->priv->conf, GPM_CONF_NOTIFY_SLEEP_FAILED_URI, NULL);
+		uri = g_settings_get_string (manager->priv->settings, GPM_SETTINGS_NOTIFY_SLEEP_FAILED_URI);
 		screen = gdk_screen_get_default();
 		ret = gtk_show_uri (screen, uri, gtk_get_current_event_time (), &error);
 		if (!ret) {
@@ -575,8 +579,8 @@ gpm_manager_sleep_failure (GpmManager *manager, gboolean is_suspend, const gchar
 	const gchar *icon;
 	GtkWidget *dialog;
 
-	/* only show this if specified in gconf */
-	show_sleep_failed = gconf_client_get_bool (manager->priv->conf, GPM_CONF_NOTIFY_SLEEP_FAILED, NULL);
+	/* only show this if specified in settings */
+	show_sleep_failed = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_NOTIFY_SLEEP_FAILED);
 
 	egg_debug ("sleep failed");
 	gpm_manager_play (manager, GPM_MANAGER_SOUND_SUSPEND_ERROR, TRUE);
@@ -612,7 +616,7 @@ gpm_manager_sleep_failure (GpmManager *manager, gboolean is_suspend, const gchar
 	gtk_window_set_icon_name (GTK_WINDOW(dialog), icon);
 
 	/* show a button? */
-	uri = gconf_client_get_string (manager->priv->conf, GPM_CONF_NOTIFY_SLEEP_FAILED_URI, NULL);
+	uri = g_settings_get_string (manager->priv->settings, GPM_SETTINGS_NOTIFY_SLEEP_FAILED_URI);
 	if (uri != NULL && uri[0] != '\0') {
 		/* TRANSLATORS: button text, visit the suspend help website */
 		gtk_dialog_add_button (GTK_DIALOG (dialog), _("Visit help page"), GTK_RESPONSE_HELP);
@@ -678,22 +682,19 @@ gpm_manager_action_hibernate (GpmManager *manager, const gchar *reason)
  * @policy: The policy that we should do, e.g. "suspend"
  * @reason: The reason we are performing the policy action, e.g. "battery critical"
  *
- * Does one of the policy actions specified in gconf.
+ * Does one of the policy actions specified in the settings.
  **/
 static gboolean
 gpm_manager_perform_policy (GpmManager  *manager, const gchar *policy_key, const gchar *reason)
 {
-	gchar *action = NULL;
 	GpmActionPolicy policy;
 
 	/* are we inhibited? */
 	if (gpm_manager_is_inhibit_valid (manager, FALSE, "policy action") == FALSE)
 		return FALSE;
 
-	action = gconf_client_get_string (manager->priv->conf, policy_key, NULL);
-	egg_debug ("action: %s set to %s (%s)", policy_key, action, reason);
-	policy = gpm_action_policy_from_string (action);
-
+	policy = g_settings_get_enum (manager->priv->settings, policy_key);
+	egg_debug ("action: %s set to %i (%s)", policy_key, policy, reason);
 	if (policy == GPM_ACTION_POLICY_NOTHING) {
 		egg_debug ("doing nothing, reason: %s", reason);
 	} else if (policy == GPM_ACTION_POLICY_SUSPEND) {
@@ -716,10 +717,9 @@ gpm_manager_perform_policy (GpmManager  *manager, const gchar *policy_key, const
 		gpm_session_logout (session);
 		g_object_unref (session);
 	} else {
-		egg_warning ("unknown action %s", action);
+		egg_warning ("unknown action %i", policy);
 	}
 
-	g_free (action);
 	return TRUE;
 }
 
@@ -728,21 +728,19 @@ gpm_manager_perform_policy (GpmManager  *manager, const gchar *policy_key, const
  * @manager: This class instance
  *
  * This callback is called when we want to sleep. Use the users
- * preference from gconf, but change it if we can't do the action.
+ * preference from the settings, but change it if we can't do the action.
  **/
 static void
 gpm_manager_idle_do_sleep (GpmManager *manager)
 {
-	gchar *action = NULL;
 	gboolean ret;
 	GError *error = NULL;
 	GpmActionPolicy policy;
 
 	if (!manager->priv->on_battery)
-		action = gconf_client_get_string (manager->priv->conf, GPM_CONF_ACTIONS_SLEEP_TYPE_AC, NULL);
+		policy = g_settings_get_enum (manager->priv->settings, GPM_SETTINGS_ACTION_SLEEP_TYPE_AC);
 	else
-		action = gconf_client_get_string (manager->priv->conf, GPM_CONF_ACTIONS_SLEEP_TYPE_BATT, NULL);
-	policy = gpm_action_policy_from_string (action);
+		policy = g_settings_get_enum (manager->priv->settings, GPM_SETTINGS_ACTION_SLEEP_TYPE_BATT);
 
 	if (policy == GPM_ACTION_POLICY_NOTHING) {
 		egg_debug ("doing nothing as system idle action");
@@ -775,7 +773,6 @@ gpm_manager_idle_do_sleep (GpmManager *manager)
 			}
 		}
 	}
-	g_free (action);
 }
 
 /**
@@ -839,13 +836,13 @@ gpm_manager_lid_button_pressed (GpmManager *manager, gboolean pressed)
 
 	if (!manager->priv->on_battery) {
 		egg_debug ("Performing AC policy");
-		gpm_manager_perform_policy (manager, GPM_CONF_BUTTON_LID_AC,
+		gpm_manager_perform_policy (manager, GPM_SETTINGS_BUTTON_LID_AC,
 					    "Lid closed on AC power.");
 		return;
 	}
 
 	egg_debug ("Performing battery policy");
-	gpm_manager_perform_policy (manager, GPM_CONF_BUTTON_LID_BATT,
+	gpm_manager_perform_policy (manager, GPM_SETTINGS_BUTTON_LID_BATT,
 				    "Lid closed on battery power.");
 }
 
@@ -928,13 +925,13 @@ gpm_manager_button_pressed_cb (GpmButton *button, const gchar *type, GpmManager
 	}
 
 	if (g_strcmp0 (type, GPM_BUTTON_POWER) == 0) {
-		gpm_manager_perform_policy (manager, GPM_CONF_BUTTON_POWER, "The power button has been pressed.");
+		gpm_manager_perform_policy (manager, GPM_SETTINGS_BUTTON_POWER, "The power button has been pressed.");
 	} else if (g_strcmp0 (type, GPM_BUTTON_SLEEP) == 0) {
-		gpm_manager_perform_policy (manager, GPM_CONF_BUTTON_SUSPEND, "The suspend button has been pressed.");
+		gpm_manager_perform_policy (manager, GPM_SETTINGS_BUTTON_SUSPEND, "The suspend button has been pressed.");
 	} else if (g_strcmp0 (type, GPM_BUTTON_SUSPEND) == 0) {
-		gpm_manager_perform_policy (manager, GPM_CONF_BUTTON_SUSPEND, "The suspend button has been pressed.");
+		gpm_manager_perform_policy (manager, GPM_SETTINGS_BUTTON_SUSPEND, "The suspend button has been pressed.");
 	} else if (g_strcmp0 (type, GPM_BUTTON_HIBERNATE) == 0) {
-		gpm_manager_perform_policy (manager, GPM_CONF_BUTTON_HIBERNATE, "The hibernate button has been pressed.");
+		gpm_manager_perform_policy (manager, GPM_SETTINGS_BUTTON_HIBERNATE, "The hibernate button has been pressed.");
 	} else if (g_strcmp0 (type, GPM_BUTTON_LID_OPEN) == 0) {
 		gpm_manager_lid_button_pressed (manager, FALSE);
 	} else if (g_strcmp0 (type, GPM_BUTTON_LID_CLOSED) == 0) {
@@ -973,11 +970,11 @@ gpm_manager_get_spindown_timeout (GpmManager *manager)
 
 	/* get policy */
 	if (!manager->priv->on_battery) {
-		enabled = gconf_client_get_bool (manager->priv->conf, GPM_CONF_DISKS_SPINDOWN_ENABLE_AC, NULL);
-		timeout = gconf_client_get_int (manager->priv->conf, GPM_CONF_DISKS_SPINDOWN_TIMEOUT_AC, NULL);
+		enabled = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_SPINDOWN_ENABLE_AC);
+		timeout = g_settings_get_int (manager->priv->settings, GPM_SETTINGS_SPINDOWN_TIMEOUT_AC);
 	} else {
-		enabled = gconf_client_get_bool (manager->priv->conf, GPM_CONF_DISKS_SPINDOWN_ENABLE_BATT, NULL);
-		timeout = gconf_client_get_int (manager->priv->conf, GPM_CONF_DISKS_SPINDOWN_TIMEOUT_BATT, NULL);
+		enabled = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_SPINDOWN_ENABLE_BATT);
+		timeout = g_settings_get_int (manager->priv->settings, GPM_SETTINGS_SPINDOWN_TIMEOUT_BATT);
 	}
 	if (!enabled)
 		timeout = 0;
@@ -1048,15 +1045,15 @@ gpm_manager_client_changed_cb (UpClient *client, GpmManager *manager)
 
 	/* We do the lid close on battery action if the ac adapter is removed
 	   when the laptop is closed and on battery. Fixes #331655 */
-	event_when_closed = gconf_client_get_bool (manager->priv->conf, GPM_CONF_ACTIONS_SLEEP_WHEN_CLOSED, NULL);
+	event_when_closed = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_SLEEP_WHEN_CLOSED);
 
 	/* We keep track of the lid state so we can do the
 	   lid close on battery action if the ac adapter is removed when the laptop
 	   is closed. Fixes #331655 */
 	if (event_when_closed && on_battery && lid_is_closed) {
-		gpm_manager_perform_policy (manager, GPM_CONF_BUTTON_LID_BATT,
+		gpm_manager_perform_policy (manager, GPM_SETTINGS_BUTTON_LID_BATT,
 					    "The lid has been closed, and the ac adapter "
-					    "removed (and gconf is okay).");
+					    "removed (and GSettings is okay).");
 	}
 }
 
@@ -1076,7 +1073,7 @@ manager_critical_action_do (GpmManager *manager)
 	if (manager->priv->critical_alert_timeout_id)
 		gpm_manager_play_loop_stop (manager);
 
-	gpm_manager_perform_policy (manager, GPM_CONF_ACTIONS_CRITICAL_BATT, "Battery is critically low.");
+	gpm_manager_perform_policy (manager, GPM_SETTINGS_ACTION_CRITICAL_BATT, "Battery is critically low.");
 	return FALSE;
 }
 
@@ -1093,23 +1090,17 @@ gpm_manager_class_init (GpmManagerClass *klass)
 }
 
 /**
- * gpm_conf_gconf_key_changed_cb:
+ * gpm_manager_settings_changed_cb:
  *
- * We might have to do things when the gconf keys change; do them here.
+ * We might have to do things when the keys change; do them here.
  **/
 static void
-gpm_conf_gconf_key_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, GpmManager *manager)
+gpm_manager_settings_changed_cb (GSettings *settings, const gchar *key, GpmManager *manager)
 {
-	GConfValue *value;
-
-	value = gconf_entry_get_value (entry);
-	if (value == NULL)
-		return;
-
-	if (g_strcmp0 (entry->key, GPM_CONF_TIMEOUT_SLEEP_COMPUTER_BATT) == 0 ||
-	    g_strcmp0 (entry->key, GPM_CONF_TIMEOUT_SLEEP_COMPUTER_AC) == 0 ||
-	    g_strcmp0 (entry->key, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_BATT) == 0 ||
-	    g_strcmp0 (entry->key, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_AC) == 0)
+	if (g_strcmp0 (key, GPM_SETTINGS_SLEEP_COMPUTER_BATT) == 0 ||
+	    g_strcmp0 (key, GPM_SETTINGS_SLEEP_COMPUTER_AC) == 0 ||
+	    g_strcmp0 (key, GPM_SETTINGS_SLEEP_DISPLAY_BATT) == 0 ||
+	    g_strcmp0 (key, GPM_SETTINGS_SLEEP_DISPLAY_AC) == 0)
 		gpm_manager_sync_policy_sleep (manager);
 }
 
@@ -1154,7 +1145,7 @@ gpm_manager_perhaps_recall_response_cb (GtkDialog *dialog, gint response_id, Gpm
 
 	/* don't show this again */
 	if (response_id == GTK_RESPONSE_CANCEL) {
-		gconf_client_set_bool (manager->priv->conf, GPM_CONF_NOTIFY_PERHAPS_RECALL, FALSE, NULL);
+		g_settings_set_boolean (manager->priv->settings, GPM_SETTINGS_NOTIFY_PERHAPS_RECALL, FALSE);
 		goto out;
 	}
 
@@ -1224,6 +1215,7 @@ static void
 gpm_manager_engine_perhaps_recall_cb (GpmEngine *engine, UpDevice *device, gchar *oem_vendor, gchar *website, GpmManager *manager)
 {
 	gboolean ret;
+	guint timer_id;
 
 	/* don't show when running under GDM */
 	if (g_getenv ("RUNNING_UNDER_GDM") != NULL) {
@@ -1232,9 +1224,9 @@ gpm_manager_engine_perhaps_recall_cb (GpmEngine *engine, UpDevice *device, gchar
 	}
 
 	/* already shown, and dismissed */
-	ret = gconf_client_get_bool (manager->priv->conf, GPM_CONF_NOTIFY_PERHAPS_RECALL, NULL);
+	ret = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_NOTIFY_PERHAPS_RECALL);
 	if (!ret) {
-		egg_debug ("GConf prevents notification: %s", GPM_CONF_NOTIFY_PERHAPS_RECALL);
+		egg_debug ("GConf prevents notification: %s", GPM_SETTINGS_NOTIFY_PERHAPS_RECALL);
 		return;
 	}
 
@@ -1242,7 +1234,11 @@ gpm_manager_engine_perhaps_recall_cb (GpmEngine *engine, UpDevice *device, gchar
 	g_object_set_data_full (G_OBJECT (manager), "recall-oem-website", (gpointer) g_strdup (website), (GDestroyNotify) g_free);
 
 	/* delay by a few seconds so the panel can load */
-	g_timeout_add_seconds (GPM_MANAGER_RECALL_DELAY, (GSourceFunc) gpm_manager_perhaps_recall_delay_cb, manager);
+	timer_id = g_timeout_add_seconds (GPM_MANAGER_RECALL_DELAY,
+					  (GSourceFunc) gpm_manager_perhaps_recall_delay_cb, manager);
+#if GLIB_CHECK_VERSION(2,25,8)
+	g_source_set_name_by_id (timer_id, "[GpmManager] perhaps-recall");
+#endif
 }
 
 /**
@@ -1312,8 +1308,8 @@ gpm_manager_engine_fully_charged_cb (GpmEngine *engine, UpDevice *device, GpmMan
 	guint plural = 1;
 	const gchar *title;
 
-	/* only action this if specified in gconf */
-	ret = gconf_client_get_bool (manager->priv->conf, GPM_CONF_NOTIFY_FULLY_CHARGED, NULL);
+	/* only action this if specified in the setings */
+	ret = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_NOTIFY_FULLY_CHARGED);
 	if (!ret) {
 		egg_debug ("no notification");
 		goto out;
@@ -1366,8 +1362,8 @@ gpm_manager_engine_discharging_cb (GpmEngine *engine, UpDevice *device, GpmManag
 	GIcon *icon = NULL;
 	const gchar *kind_desc;
 
-	/* only action this if specified in gconf */
-	ret = gconf_client_get_bool (manager->priv->conf, GPM_CONF_NOTIFY_DISCHARGING, NULL);
+	/* only action this if specified in the settings */
+	ret = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_NOTIFY_DISCHARGING);
 	if (!ret) {
 		egg_debug ("no notification");
 		goto out;
@@ -1578,7 +1574,6 @@ gpm_manager_engine_charge_critical_cb (GpmEngine *engine, UpDevice *device, GpmM
 {
 	const gchar *title = NULL;
 	gchar *message = NULL;
-	gchar *action;
 	GIcon *icon = NULL;
 	UpDeviceKind kind;
 	gdouble percentage;
@@ -1614,8 +1609,7 @@ gpm_manager_engine_charge_critical_cb (GpmEngine *engine, UpDevice *device, GpmM
 		}
 
 		/* we have to do different warnings depending on the policy */
-		action = gconf_client_get_string (manager->priv->conf, GPM_CONF_ACTIONS_CRITICAL_BATT, NULL);
-		policy = gpm_action_policy_from_string (action);
+		policy = g_settings_get_enum (manager->priv->settings, GPM_SETTINGS_ACTION_CRITICAL_BATT);
 
 		/* use different text for different actions */
 		if (policy == GPM_ACTION_POLICY_NOTHING) {
@@ -1635,7 +1629,6 @@ gpm_manager_engine_charge_critical_cb (GpmEngine *engine, UpDevice *device, GpmM
 			message = g_strdup_printf (_("Computer will shutdown very soon unless it is plugged in."));
 		}
 
-		g_free (action);
 	} else if (kind == UP_DEVICE_KIND_UPS) {
 		gchar *remaining_text;
 
@@ -1747,11 +1740,11 @@ static void
 gpm_manager_engine_charge_action_cb (GpmEngine *engine, UpDevice *device, GpmManager *manager)
 {
 	const gchar *title = NULL;
-	gchar *action;
 	gchar *message = NULL;
 	GIcon *icon = NULL;
 	UpDeviceKind kind;
 	GpmActionPolicy policy;
+	guint timer_id;
 
 	/* get device properties */
 	g_object_get (device,
@@ -1772,8 +1765,7 @@ gpm_manager_engine_charge_action_cb (GpmEngine *engine, UpDevice *device, GpmMan
 		title = _("Laptop battery critically low");
 
 		/* we have to do different warnings depending on the policy */
-		action = gconf_client_get_string (manager->priv->conf, GPM_CONF_ACTIONS_CRITICAL_BATT, NULL);
-		policy = gpm_action_policy_from_string (action);
+		policy = g_settings_get_enum (manager->priv->settings, GPM_SETTINGS_ACTION_CRITICAL_BATT);
 
 		/* use different text for different actions */
 		if (policy == GPM_ACTION_POLICY_NOTHING) {
@@ -1800,18 +1792,18 @@ gpm_manager_engine_charge_action_cb (GpmEngine *engine, UpDevice *device, GpmMan
 					      "this computer is about to shutdown."));
 		}
 
-		g_free (action);
-
 		/* wait 20 seconds for user-panic */
-		g_timeout_add_seconds (20, (GSourceFunc) manager_critical_action_do, manager);
+		timer_id = g_timeout_add_seconds (20, (GSourceFunc) manager_critical_action_do, manager);
+#if GLIB_CHECK_VERSION(2,25,8)
+		g_source_set_name_by_id (timer_id, "[GpmManager] battery critical-action");
+#endif
 
 	} else if (kind == UP_DEVICE_KIND_UPS) {
 		/* TRANSLATORS: UPS is really, really, low */
 		title = _("UPS critically low");
 
 		/* we have to do different warnings depending on the policy */
-		action = gconf_client_get_string (manager->priv->conf, GPM_CONF_ACTIONS_CRITICAL_UPS, NULL);
-		policy = gpm_action_policy_from_string (action);
+		policy = g_settings_get_enum (manager->priv->settings, GPM_SETTINGS_ACTION_CRITICAL_UPS);
 
 		/* use different text for different actions */
 		if (policy == GPM_ACTION_POLICY_NOTHING) {
@@ -1832,9 +1824,10 @@ gpm_manager_engine_charge_action_cb (GpmEngine *engine, UpDevice *device, GpmMan
 		}
 
 		/* wait 20 seconds for user-panic */
-		g_timeout_add_seconds (20, (GSourceFunc) manager_critical_action_do, manager);
-
-		g_free (action);
+		timer_id = g_timeout_add_seconds (20, (GSourceFunc) manager_critical_action_do, manager);
+#if GLIB_CHECK_VERSION(2,25,8)
+		g_source_set_name_by_id (timer_id, "[GpmManager] ups critical-action");
+#endif
 	}
 
 	/* not all types have actions */
@@ -1904,8 +1897,12 @@ gpm_manager_reset_just_resumed_cb (gpointer user_data)
 static void
 gpm_manager_control_resume_cb (GpmControl *control, GpmControlAction action, GpmManager *manager)
 {
+	guint timer_id;
 	manager->priv->just_resumed = TRUE;
-	g_timeout_add_seconds (1, gpm_manager_reset_just_resumed_cb, manager);
+	timer_id = g_timeout_add_seconds (1, gpm_manager_reset_just_resumed_cb, manager);
+#if GLIB_CHECK_VERSION(2,25,8)
+	g_source_set_name_by_id (timer_id, "[GpmManager] just-resumed");
+#endif
 }
 
 /**
@@ -1943,7 +1940,9 @@ gpm_manager_init (GpmManager *manager)
 	manager->priv->notification_discharging = NULL;
 	manager->priv->notification_fully_charged = NULL;
 	manager->priv->disks = gpm_disks_new ();
-	manager->priv->conf = gconf_client_get_default ();
+	manager->priv->settings = g_settings_new (GPM_SETTINGS_SCHEMA);
+	g_signal_connect (manager->priv->settings, "changed",
+			  G_CALLBACK (gpm_manager_settings_changed_cb), manager);
 	manager->priv->client = up_client_new ();
 	g_signal_connect (manager->priv->client, "changed",
 			  G_CALLBACK (gpm_manager_client_changed_cb), manager);
@@ -1951,16 +1950,9 @@ gpm_manager_init (GpmManager *manager)
 	/* use libnotify */
 	notify_init (GPM_NAME);
 
-	/* watch gnome-power-manager keys */
-	gconf_client_add_dir (manager->priv->conf, GPM_CONF_DIR,
-			      GCONF_CLIENT_PRELOAD_RECURSIVE, NULL);
-	gconf_client_notify_add (manager->priv->conf, GPM_CONF_DIR,
-				 (GConfClientNotifyFunc) gpm_conf_gconf_key_changed_cb,
-				 manager, NULL, NULL);
-
 	/* check to see if the user has installed the schema properly */
-	version = gconf_client_get_int (manager->priv->conf, GPM_CONF_SCHEMA_VERSION, NULL);
-	if (version != GPM_CONF_SCHEMA_ID) {
+	version = g_settings_get_int (manager->priv->settings, GPM_SETTINGS_SCHEMA_VERSION);
+	if (version != GPM_SETTINGS_SCHEMA_ID) {
 		gpm_manager_notify (manager, &manager->priv->notification_general,
 				    /* TRANSLATORS: there was in install problem */
 				    _("Install problem!"),
@@ -1970,7 +1962,7 @@ gpm_manager_init (GpmManager *manager)
 				    GPM_MANAGER_NOTIFY_TIMEOUT_LONG,
 				    GTK_STOCK_DIALOG_WARNING,
 				    NOTIFY_URGENCY_NORMAL);
-		egg_error ("no gconf schema installed!");
+		egg_error ("no GSettings schema installed!");
 	}
 
 	/* coldplug so we are in the correct state at startup */
@@ -2004,7 +1996,7 @@ gpm_manager_init (GpmManager *manager)
 			  G_CALLBACK (gpm_manager_idle_changed_cb), manager);
 
 	/* set up the check_type_cpu, so we can disable the CPU load check */
-	check_type_cpu = gconf_client_get_bool (manager->priv->conf, GPM_CONF_IDLE_CHECK_CPU, NULL);
+	check_type_cpu = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_IDLE_CHECK_CPU);
 	gpm_idle_set_check_cpu (manager->priv->idle, check_type_cpu);
 
 	manager->priv->dpms = gpm_dpms_new ();
@@ -2083,7 +2075,7 @@ gpm_manager_finalize (GObject *object)
 	if (manager->priv->critical_alert_timeout_id != 0)
 		g_source_remove (manager->priv->critical_alert_timeout_id);
 
-	g_object_unref (manager->priv->conf);
+	g_object_unref (manager->priv->settings);
 	g_object_unref (manager->priv->disks);
 	g_object_unref (manager->priv->dpms);
 	g_object_unref (manager->priv->idle);
