@@ -32,10 +32,8 @@
 #include <libupower-glib/upower.h>
 
 #include "egg-debug.h"
-#include "egg-color.h"
-#include "egg-array-float.h"
-#include "egg-unique.h"
 
+#include "gpm-array-float.h"
 #include "gpm-common.h"
 #include "gpm-stock-icons.h"
 #include "gpm-upower.h"
@@ -49,7 +47,7 @@ gchar *current_device = NULL;
 static const gchar *history_type;
 static const gchar *stats_type;
 static guint history_time;
-static GConfClient *gconf_client;
+static GSettings *settings;
 static gfloat sigma_smoothing = 0.0f;
 static UpWakeups *wakeups = NULL;
 static GtkWidget *graph_history = NULL;
@@ -115,7 +113,7 @@ enum {
  * gpm_stats_button_help_cb:
  **/
 static void
-gpm_stats_button_help_cb (GtkWidget *widget, gboolean data)
+gpm_stats_button_help_cb (GtkWidget *widget, gpointer user_data)
 {
 	gpm_help_display ("statistics");
 }
@@ -236,24 +234,24 @@ gpm_stats_update_smooth_data (GPtrArray *list)
 	GpmPointObj *point;
 	GpmPointObj *point_new;
 	GPtrArray *new;
-	EggArrayFloat *raw;
-	EggArrayFloat *convolved;
-	EggArrayFloat *outliers;
-	EggArrayFloat *gaussian = NULL;
+	GpmArrayFloat *raw;
+	GpmArrayFloat *convolved;
+	GpmArrayFloat *outliers;
+	GpmArrayFloat *gaussian = NULL;
 
-	/* convert the y data to a EggArrayFloat array */
-	raw = egg_array_float_new (list->len);
+	/* convert the y data to a GpmArrayFloat array */
+	raw = gpm_array_float_new (list->len);
 	for (i=0; i<list->len; i++) {
 		point = (GpmPointObj *) g_ptr_array_index (list, i);
-		egg_array_float_set (raw, i, point->y);
+		gpm_array_float_set (raw, i, point->y);
 	}
 
 	/* remove any outliers */
-	outliers = egg_array_float_remove_outliers (raw, 3, 0.1);
+	outliers = gpm_array_float_remove_outliers (raw, 3, 0.1);
 
 	/* convolve with gaussian */
-	gaussian = egg_array_float_compute_gaussian (15, sigma_smoothing);
-	convolved = egg_array_float_convolve (outliers, gaussian);
+	gaussian = gpm_array_float_compute_gaussian (15, sigma_smoothing);
+	convolved = gpm_array_float_convolve (outliers, gaussian);
 
 	/* add the smoothed data back into a new array */
 	new = g_ptr_array_new_with_free_func ((GDestroyNotify) gpm_point_obj_free);
@@ -262,15 +260,15 @@ gpm_stats_update_smooth_data (GPtrArray *list)
 		point_new = g_new0 (GpmPointObj, 1);
 		point_new->color = point->color;
 		point_new->x = point->x;
-		point_new->y = egg_array_float_get (convolved, i);
+		point_new->y = gpm_array_float_get (convolved, i);
 		g_ptr_array_add (new, point_new);
 	}
 
 	/* free data */
-	egg_array_float_free (gaussian);
-	egg_array_float_free (raw);
-	egg_array_float_free (convolved);
-	egg_array_float_free (outliers);
+	gpm_array_float_free (gaussian);
+	gpm_array_float_free (raw);
+	gpm_array_float_free (convolved);
+	gpm_array_float_free (outliers);
 
 	return new;
 }
@@ -621,18 +619,18 @@ gpm_stats_update_info_page_history (UpDevice *device)
 		point->x = (gint32) up_history_item_get_time (item) - offset;
 		point->y = up_history_item_get_value (item);
 		if (up_history_item_get_state (item) == UP_DEVICE_STATE_CHARGING)
-			point->color = egg_color_from_rgb (255, 0, 0);
+			point->color = gpm_color_from_rgb (255, 0, 0);
 		else if (up_history_item_get_state (item) == UP_DEVICE_STATE_DISCHARGING)
-			point->color = egg_color_from_rgb (0, 0, 255);
+			point->color = gpm_color_from_rgb (0, 0, 255);
 		else if (up_history_item_get_state (item) == UP_DEVICE_STATE_PENDING_CHARGE)
-			point->color = egg_color_from_rgb (200, 0, 0);
+			point->color = gpm_color_from_rgb (200, 0, 0);
 		else if (up_history_item_get_state (item) == UP_DEVICE_STATE_PENDING_DISCHARGE)
-			point->color = egg_color_from_rgb (0, 0, 200);
+			point->color = gpm_color_from_rgb (0, 0, 200);
 		else {
 			if (g_strcmp0 (history_type, GPM_HISTORY_RATE_VALUE) == 0)
-				point->color = egg_color_from_rgb (255, 255, 255);
+				point->color = gpm_color_from_rgb (255, 255, 255);
 			else
-				point->color = egg_color_from_rgb (0, 255, 0);
+				point->color = gpm_color_from_rgb (0, 255, 0);
 		}
 		g_ptr_array_add (new, point);
 	}
@@ -724,7 +722,7 @@ gpm_stats_update_info_page_stats (UpDevice *device)
 			point->y = up_stats_item_get_value (item);
 		else
 			point->y = up_stats_item_get_accuracy (item);
-		point->color = egg_color_from_rgb (255, 0, 0);
+		point->color = gpm_color_from_rgb (255, 0, 0);
 		g_ptr_array_add (new, point);
 	}
 
@@ -1092,7 +1090,7 @@ gpm_stats_notebook_changed_cb (GtkNotebook *notebook, GtkNotebookPage *page, gin
 	gpm_stats_set_title (GTK_WINDOW (widget), page_num);
 
 	/* save page in gconf */
-	gconf_client_set_int (gconf_client, GPM_CONF_INFO_PAGE_NUMBER, page_num, NULL);
+	g_settings_set_int (settings, GPM_SETTINGS_INFO_PAGE_NUMBER, page_num);
 
 	if (current_device == NULL)
 		return;
@@ -1124,7 +1122,7 @@ gpm_stats_button_update_ui (void)
  * gpm_stats_devices_treeview_clicked_cb:
  **/
 static void
-gpm_stats_devices_treeview_clicked_cb (GtkTreeSelection *selection, gboolean data)
+gpm_stats_devices_treeview_clicked_cb (GtkTreeSelection *selection, gpointer user_data)
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
@@ -1136,7 +1134,7 @@ gpm_stats_devices_treeview_clicked_cb (GtkTreeSelection *selection, gboolean dat
 		gtk_tree_model_get (model, &iter, GPM_DEVICES_COLUMN_ID, &current_device, -1);
 
 		/* save device in gconf */
-		gconf_client_set_string (gconf_client, GPM_CONF_INFO_LAST_DEVICE, current_device, NULL);
+		g_settings_set_string (settings, GPM_SETTINGS_INFO_LAST_DEVICE, current_device);
 
 		/* show transaction_id */
 		egg_debug ("selected row is: %s", current_device);
@@ -1156,17 +1154,6 @@ gpm_stats_devices_treeview_clicked_cb (GtkTreeSelection *selection, gboolean dat
 	}
 }
 
-/**
- * gpm_stats_window_activated_cb
- **/
-static void
-gpm_stats_window_activated_cb (EggUnique *egg_unique, gpointer data)
-{
-	GtkWidget *widget;
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_stats"));
-	gtk_window_present (GTK_WINDOW (widget));
-}
-
 /**
  * gpm_stats_add_device:
  **/
@@ -1311,7 +1298,7 @@ gpm_stats_history_type_combo_changed_cb (GtkWidget *widget, gpointer data)
 	g_free (value);
 
 	/* save to gconf */
-	gconf_client_set_string (gconf_client, GPM_CONF_INFO_HISTORY_TYPE, history_type, NULL);
+	g_settings_set_string (settings, GPM_SETTINGS_INFO_HISTORY_TYPE, history_type);
 }
 
 /**
@@ -1362,7 +1349,7 @@ gpm_stats_type_combo_changed_cb (GtkWidget *widget, gpointer data)
 	g_free (value);
 
 	/* save to gconf */
-	gconf_client_set_string (gconf_client, GPM_CONF_INFO_STATS_TYPE, stats_type, NULL);
+	g_settings_set_string (settings, GPM_SETTINGS_INFO_STATS_TYPE, stats_type);
 }
 
 /**
@@ -1387,7 +1374,7 @@ gpm_stats_range_combo_changed (GtkWidget *widget, gpointer data)
 		g_assert (FALSE);
 
 	/* save to gconf */
-	gconf_client_set_int (gconf_client, GPM_CONF_INFO_HISTORY_TIME, history_time, NULL);
+	g_settings_set_int (settings, GPM_SETTINGS_INFO_HISTORY_TIME, history_time);
 
 	gpm_stats_button_update_ui ();
 	g_free (value);
@@ -1402,7 +1389,7 @@ gpm_stats_smooth_checkbox_history_cb (GtkWidget *widget, gpointer data)
 {
 	gboolean checked;
 	checked = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-	gconf_client_set_bool (gconf_client, GPM_CONF_INFO_HISTORY_GRAPH_SMOOTH, checked, NULL);
+	g_settings_set_boolean (settings, GPM_SETTINGS_INFO_HISTORY_GRAPH_SMOOTH, checked);
 	gpm_stats_button_update_ui ();
 }
 
@@ -1415,7 +1402,7 @@ gpm_stats_smooth_checkbox_stats_cb (GtkWidget *widget, gpointer data)
 {
 	gboolean checked;
 	checked = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-	gconf_client_set_bool (gconf_client, GPM_CONF_INFO_STATS_GRAPH_SMOOTH, checked, NULL);
+	g_settings_set_boolean (settings, GPM_SETTINGS_INFO_STATS_GRAPH_SMOOTH, checked);
 	gpm_stats_button_update_ui ();
 }
 
@@ -1428,7 +1415,7 @@ gpm_stats_points_checkbox_history_cb (GtkWidget *widget, gpointer data)
 {
 	gboolean checked;
 	checked = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-	gconf_client_set_bool (gconf_client, GPM_CONF_INFO_HISTORY_GRAPH_POINTS, checked, NULL);
+	g_settings_set_boolean (settings, GPM_SETTINGS_INFO_HISTORY_GRAPH_POINTS, checked);
 	gpm_stats_button_update_ui ();
 }
 
@@ -1441,7 +1428,7 @@ gpm_stats_points_checkbox_stats_cb (GtkWidget *widget, gpointer data)
 {
 	gboolean checked;
 	checked = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-	gconf_client_set_bool (gconf_client, GPM_CONF_INFO_STATS_GRAPH_POINTS, checked, NULL);
+	g_settings_set_boolean (settings, GPM_SETTINGS_INFO_STATS_GRAPH_POINTS, checked);
 	gpm_stats_button_update_ui ();
 }
 
@@ -1502,6 +1489,25 @@ gpm_stats_highlight_device (const gchar *object_path)
 	}
 }
 
+/**
+ * gpm_stats_delete_event_cb:
+ **/
+static gboolean
+gpm_stats_delete_event_cb (GtkWidget *widget, GdkEvent *event, GtkApplication *application)
+{
+	gtk_application_quit (application);
+	return FALSE;
+}
+
+/**
+ * gpm_stats_button_close_cb:
+ **/
+static void
+gpm_stats_button_close_cb (GtkWidget *widget, GtkApplication *application)
+{
+	gtk_application_quit (application);
+}
+
 /**
  * main:
  **/
@@ -1513,7 +1519,7 @@ main (int argc, char *argv[])
 	GtkBox *box;
 	GtkWidget *widget;
 	GtkTreeSelection *selection;
-	EggUnique *egg_unique;
+	GtkApplication *application;
 	gboolean ret;
 	UpClient *client;
 	GPtrArray *devices;
@@ -1558,19 +1564,14 @@ main (int argc, char *argv[])
 	gtk_init (&argc, &argv);
 
 	/* are we already activated? */
-	egg_unique = egg_unique_new ();
-	ret = egg_unique_assign (egg_unique, "org.gnome.PowerManager.Statistics");
-	if (!ret)
-		goto unique_out;
-	g_signal_connect (egg_unique, "activated",
-			  G_CALLBACK (gpm_stats_window_activated_cb), NULL);
+	application = gtk_application_new ("org.gnome.PowerManager.Statistics", &argc, &argv);
 
 	/* add application specific icons to search path */
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
                                            GPM_DATA G_DIR_SEPARATOR_S "icons");
 
 	/* get data from gconf */
-	gconf_client = gconf_client_get_default ();
+	settings = g_settings_new (GPM_SETTINGS_SCHEMA);
 
 	/* get UI */
 	builder = gtk_builder_new ();
@@ -1595,14 +1596,17 @@ main (int argc, char *argv[])
 	gtk_widget_show (graph_statistics);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_stats"));
+	gtk_application_add_window (application, GTK_WINDOW (widget));
 	gtk_window_set_default_size (GTK_WINDOW(widget), 800, 500);
 	gtk_window_set_default_icon_name (GPM_STOCK_APP_ICON);
 
 	/* Get the main window quit */
-	g_signal_connect_swapped (widget, "delete_event", G_CALLBACK (gtk_main_quit), NULL);
+	g_signal_connect (widget, "delete-event",
+			  G_CALLBACK (gpm_stats_delete_event_cb), application);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_close"));
-	g_signal_connect_swapped (widget, "clicked", G_CALLBACK (gtk_main_quit), NULL);
+	g_signal_connect (widget, "clicked",
+			  G_CALLBACK (gpm_stats_button_close_cb), application);
 	gtk_widget_grab_default (widget);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_help"));
@@ -1610,31 +1614,31 @@ main (int argc, char *argv[])
 			  G_CALLBACK (gpm_stats_button_help_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_smooth_history"));
-	checked = gconf_client_get_bool (gconf_client, GPM_CONF_INFO_HISTORY_GRAPH_SMOOTH, NULL);
+	checked = g_settings_get_boolean (settings, GPM_SETTINGS_INFO_HISTORY_GRAPH_SMOOTH);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), checked);
 	g_signal_connect (widget, "clicked",
 			  G_CALLBACK (gpm_stats_smooth_checkbox_history_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_smooth_stats"));
-	checked = gconf_client_get_bool (gconf_client, GPM_CONF_INFO_STATS_GRAPH_SMOOTH, NULL);
+	checked = g_settings_get_boolean (settings, GPM_SETTINGS_INFO_STATS_GRAPH_SMOOTH);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), checked);
 	g_signal_connect (widget, "clicked",
 			  G_CALLBACK (gpm_stats_smooth_checkbox_stats_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_points_history"));
-	checked = gconf_client_get_bool (gconf_client, GPM_CONF_INFO_HISTORY_GRAPH_POINTS, NULL);
+	checked = g_settings_get_boolean (settings, GPM_SETTINGS_INFO_HISTORY_GRAPH_POINTS);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), checked);
 	g_signal_connect (widget, "clicked",
 			  G_CALLBACK (gpm_stats_points_checkbox_history_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_points_stats"));
-	checked = gconf_client_get_bool (gconf_client, GPM_CONF_INFO_STATS_GRAPH_POINTS, NULL);
+	checked = g_settings_get_boolean (settings, GPM_SETTINGS_INFO_STATS_GRAPH_POINTS);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), checked);
 	g_signal_connect (widget, "clicked",
 			  G_CALLBACK (gpm_stats_points_checkbox_stats_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "notebook1"));
-	page = gconf_client_get_int (gconf_client, GPM_CONF_INFO_PAGE_NUMBER, NULL);
+	page = g_settings_get_int (settings, GPM_SETTINGS_INFO_PAGE_NUMBER);
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), page);
 	g_signal_connect (widget, "switch-page",
 			  G_CALLBACK (gpm_stats_notebook_changed_cb), NULL);
@@ -1676,14 +1680,14 @@ main (int argc, char *argv[])
 	gpm_stats_add_wakeups_columns (GTK_TREE_VIEW (widget));
 	gtk_tree_view_columns_autosize (GTK_TREE_VIEW (widget)); /* show */
 
-	history_type = gconf_client_get_string (gconf_client, GPM_CONF_INFO_HISTORY_TYPE, NULL);
-	history_time = gconf_client_get_int (gconf_client, GPM_CONF_INFO_HISTORY_TIME, NULL);
+	history_type = g_settings_get_string (settings, GPM_SETTINGS_INFO_HISTORY_TYPE);
+	history_time = g_settings_get_int (settings, GPM_SETTINGS_INFO_HISTORY_TIME);
 	if (history_type == NULL)
 		history_type = GPM_HISTORY_CHARGE_VALUE;
 	if (history_time == 0)
 		history_time = GPM_HISTORY_HOUR_VALUE;
 
-	stats_type = gconf_client_get_string (gconf_client, GPM_CONF_INFO_STATS_TYPE, NULL);
+	stats_type = g_settings_get_string (settings, GPM_SETTINGS_INFO_STATS_TYPE);
 	if (stats_type == NULL)
 		stats_type = GPM_STATS_CHARGE_DATA_VALUE;
 
@@ -1768,7 +1772,7 @@ main (int argc, char *argv[])
 	}
 
 	if (last_device == NULL)
-		last_device = gconf_client_get_string (gconf_client, GPM_CONF_INFO_LAST_DEVICE, NULL);
+		last_device = g_settings_get_string (settings, GPM_SETTINGS_INFO_LAST_DEVICE);
 
 	/* has capability to measure wakeups */
 	ret = up_wakeups_get_has_capability (wakeups);
@@ -1800,16 +1804,16 @@ main (int argc, char *argv[])
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_stats"));
 	gtk_widget_show (widget);
 
-	gtk_main ();
+	/* run */
+	gtk_application_run (application);
 
 out:
-	g_object_unref (gconf_client);
+	g_object_unref (settings);
 	g_object_unref (client);
 	g_object_unref (wakeups);
 	g_object_unref (builder);
 	g_object_unref (list_store_info);
-unique_out:
-	g_object_unref (egg_unique);
+	g_object_unref (application);
 	g_free (last_device);
 	return 0;
 }
